Metaclass subclass:#PrivateClass
	instanceVariableNames:'owningClass'
	classVariableNames:''
	poolDictionaries:''
	category:'Kernel-Classes'
!

!PrivateClass  class methodsFor:'documentation'!

documentation
"
    A PrivateClass is much like a regular class, but it is only visible (known)
    to some owningClass.
    Its sourceCode is forced to be contained within the owning classes sourceFile.
    Therefore, privateClasses use their owning classes sourceCode information
    for access. Also, the package identifier is taken from the owningClass.
    Finally, no private history is available.

    [author:]
        Claus Gittinger

    [see also:]
        Behavior ClassDescription Class Metaclass
"
! !

!PrivateClass methodsFor:'accessing'!

owningClass
    "return my owningClass"

    ^ owningClass

    "Created: 11.10.1996 / 16:55:43 / cg"
    "Modified: 11.10.1996 / 17:35:13 / cg"
!

setOwningClass:something
    "set my owningClass - this is not a public entry"

    owningClass := something.

    "Created: 11.10.1996 / 17:11:05 / cg"
    "Modified: 11.10.1996 / 17:35:24 / cg"
! !

!PrivateClass methodsFor:'accessing - delegated'!

package
    ^ self owningClass package

    "Created: 11.10.1996 / 17:35:52 / cg"
!

package:ignored
    ^ self

    "Created: 11.10.1996 / 17:35:52 / cg"
!

sourceCodeManager
    ^ self owningClass sourceCodeManager

    "Created: 11.10.1996 / 17:37:04 / cg"
! !

!PrivateClass methodsFor:'fileOut'!

basicFileOutDefinitionOn:aStream
    "append an expression on aStream, which defines myself."

    |isVar s|

    "take care of nil-superclass"
    superclass isNil ifTrue:[
        s := 'nil'
    ] ifFalse:[
        s := (superclass name)
    ].

    aStream nextPutAll:s.
    aStream space.
    self basicFileOutInstvarTypeKeywordOn:aStream.
    aStream nextPut:$#.
    aStream nextPutAll:name.

    aStream crtab. 
    aStream nextPutAll:'instanceVariableNames:'''.
    self printInstVarNamesOn:aStream indent:16.
    aStream nextPutAll:''''.

    aStream crtab.
    aStream nextPutAll:'classVariableNames:'''.
    self printClassVarNamesOn:aStream indent:16.
    aStream nextPutAll:''''.

    aStream crtab.
    aStream nextPutAll:'poolDictionaries:'''''.

    aStream crtab.
    aStream nextPutAll:'privateIn:'.
    aStream nextPutAll:self owningClass name.
    aStream cr

    "Modified: 11.10.1996 / 18:58:42 / cg"


! !

!PrivateClass methodsFor:'queries'!

isBuiltInClass
     ^ false
! !

!PrivateClass  class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/libbasic/Attic/PrivateClass.st,v 1.4 1996-10-12 19:08:46 cg Exp $'
! !
